@@ -375,24 +375,17 @@ static inline MagickBooleanType IsFloatDefined(const float value)
   return(MagickTrue);
 }
 
-static Image *ReadCINImage(const ImageInfo *image_info,
-  ExceptionInfo *exception)
+static Image *ReadCINImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
 #define MonoColorType  1
 #define RGBColorType  3
 
-  char
-    magick[4];
-
   CINInfo
     cin;
 
   Image
     *image;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
@@ -415,14 +408,13 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     length;
 
   ssize_t
-    count;
+    count,
+    y;
 
   unsigned char
+    magick[4],
     *pixels;
 
-  size_t
-    lsb_first;
-
   /*
     Open image file.
   */
@@ -444,15 +436,13 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     File information.
   */
   offset=0;
-  count=ReadBlob(image,4,(unsigned char *) magick);
+  count=ReadBlob(image,4,magick);
   offset+=count;
   if ((count != 4) ||
       ((LocaleNCompare((char *) magick,"\200\052\137\327",4) != 0)))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  image->endian=LSBEndian;
-  lsb_first=1;
-  if ((int) (*(char *) &lsb_first) != 0)
-    image->endian=MSBEndian;
+  image->endian=(magick[0] == 0x80) && (magick[1] == 0x2a) &&
+    (magick[2] == 0x5f) && (magick[3] == 0xd7) ? MSBEndian : LSBEndian;
   cin.file.image_offset=ReadBlobLong(image);
   offset+=4;
   cin.file.generic_length=ReadBlobLong(image);
@@ -488,14 +478,14 @@ static Image *ReadCINImage(const ImageInfo *image_info,
   switch (cin.image.orientation)
   {
     default:
-    case 0:  image->orientation=TopLeftOrientation; break;
-    case 1:  image->orientation=TopRightOrientation; break;
-    case 2:  image->orientation=BottomLeftOrientation; break;
-    case 3:  image->orientation=BottomRightOrientation; break;
-    case 4:  image->orientation=LeftTopOrientation; break;
-    case 5:  image->orientation=RightTopOrientation; break;
-    case 6:  image->orientation=LeftBottomOrientation; break;
-    case 7:  image->orientation=RightBottomOrientation; break;
+    case 0: image->orientation=TopLeftOrientation; break;
+    case 1: image->orientation=TopRightOrientation; break;
+    case 2: image->orientation=BottomLeftOrientation; break;
+    case 3: image->orientation=BottomRightOrientation; break;
+    case 4: image->orientation=LeftTopOrientation; break;
+    case 5: image->orientation=RightTopOrientation; break;
+    case 6: image->orientation=LeftBottomOrientation; break;
+    case 7: image->orientation=RightBottomOrientation; break;
   }
   cin.image.number_channels=(unsigned char) ReadBlobByte(image);
   offset++;
@@ -626,20 +616,26 @@ static Image *ReadCINImage(const ImageInfo *image_info,
     cin.origination.reserve);
   if ((cin.file.image_offset > 2048) && (cin.file.user_length != 0))
     {
+      int
+        c;
+
       /*
         Image film information.
       */
       cin.film.id=ReadBlobByte(image);
       offset++;
-      if (((size_t) cin.film.id) != ~0UL)
+      c=cin.film.id;
+      if (c != ~0)
         (void) FormatImageProperty(image,"dpx:film.id","%d",cin.film.id);
       cin.film.type=ReadBlobByte(image);
       offset++;
-      if (((size_t) cin.film.type) != ~0UL)
+      c=cin.film.type;
+      if (c != ~0)
         (void) FormatImageProperty(image,"dpx:film.type","%d",cin.film.type);
       cin.film.offset=ReadBlobByte(image);
       offset++;
-      if (((size_t) cin.film.offset) != ~0UL)
+      c=cin.film.offset;
+      if (c != ~0)
         (void) FormatImageProperty(image,"dpx:film.offset","%d",
           cin.film.offset);
       cin.film.reserve1=ReadBlobByte(image);
@@ -681,7 +677,9 @@ static Image *ReadCINImage(const ImageInfo *image_info,
       /*
         User defined data.
       */
-      profile=AcquireStringInfo(cin.file.user_length);
+      profile=BlobToStringInfo((const void *) NULL,cin.file.user_length);
+      if (profile == (StringInfo *) NULL)
+        ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       offset+=ReadBlob(image,GetStringInfoLength(profile),
         GetStringInfoDatum(profile));
       (void) SetImageProfile(image,"dpx:user.data",profile);
@@ -775,6 +773,7 @@ ModuleExport size_t RegisterCINImage(void)
   entry->decoder=(DecodeImageHandler *) ReadCINImage;
   entry->encoder=(EncodeImageHandler *) WriteCINImage;
   entry->magick=(IsImageFormatHandler *) IsCIN;
+  entry->adjoin=MagickFalse;
   entry->description=ConstantString("Cineon Image File");
   entry->module=ConstantString("CIN");
   (void) RegisterMagickInfo(entry);
@@ -853,9 +852,6 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   const StringInfo
     *profile;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
@@ -878,7 +874,8 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     length;
 
   ssize_t
-    count;
+    count,
+    y;
 
   struct tm
     local_time;
@@ -1068,12 +1065,12 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   cin.origination.x_pitch=0.0f;
   value=GetCINProperty(image_info,image,"dpx:origination.x_pitch");
   if (value != (const char *) NULL)
-    cin.origination.x_pitch=StringToDouble(value);
+    cin.origination.x_pitch=StringToDouble(value,(char **) NULL);
   offset+=WriteBlobFloat(image,cin.origination.x_pitch);
   cin.origination.y_pitch=0.0f;
   value=GetCINProperty(image_info,image,"dpx:origination.y_pitch");
   if (value != (const char *) NULL)
-    cin.origination.y_pitch=StringToDouble(value);
+    cin.origination.y_pitch=StringToDouble(value,(char **) NULL);
   offset+=WriteBlobFloat(image,cin.origination.y_pitch);
   cin.origination.gamma=image->gamma;
   offset+=WriteBlobFloat(image,cin.origination.gamma);
@@ -1121,7 +1118,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   cin.film.frame_rate=0.0f;
   value=GetCINProperty(image_info,image,"dpx:film.frame_rate");
   if (value != (const char *) NULL)
-    cin.film.frame_rate=StringToDouble(value);
+    cin.film.frame_rate=StringToDouble(value,(char **) NULL);
   offset+=WriteBlobFloat(image,cin.film.frame_rate);
   value=GetCINProperty(image_info,image,"dpx:film.frame_id");
   if (value != (const char *) NULL)
@@ -1155,7 +1152,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
   if (0)
     {
       quantum_type=GrayQuantum;
-      length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
+      length=GetBytesPerRow(image->columns,1UL,image->depth,MagickTrue);
     }
   for (y=0; y < (ssize_t) image->rows; y++)
   {
