@@ -67,6 +67,7 @@
 #include "magick/string_.h"
 #include "magick/module.h"
 #include "magick/utility.h"
+#include "magick/utility-private.h"
 
 typedef struct
 {
@@ -102,11 +103,10 @@ static void InsertRow(ssize_t depth,unsigned char *p,ssize_t y,Image *image)
   IndexPacket index;
   register IndexPacket *indexes;
 
-
   index=(IndexPacket) 0;
   exception=(&image->exception);
   switch (depth)
-    {
+  {
     case 1:  /* Convert bitmap scanline. */
       {
         q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
@@ -114,22 +114,20 @@ static void InsertRow(ssize_t depth,unsigned char *p,ssize_t y,Image *image)
           break;
         indexes=GetAuthenticIndexQueue(image);
         for (x=0; x < ((ssize_t) image->columns-7); x+=8)
+        {
+          for (bit=0; bit < 8; bit++)
           {
-            for (bit=0; bit < 8; bit++)
-              {
-                index=(IndexPacket) ((((*p) & (0x80 >> bit)) != 0) ? 0x01 : 0x00);
-                indexes[x+bit]=index;
-                *q++=image->colormap[(ssize_t) index];
-              }
-            p++;
+            index=(IndexPacket) ((((*p) & (0x80 >> bit)) != 0) ? 0x01 : 0x00);
+            SetPixelIndex(indexes+x+bit,index);
           }
+          p++;
+        }
         if ((image->columns % 8) != 0)
           {
             for (bit=0; bit < (image->columns % 8); bit++)
               {
                 index=(IndexPacket) ((((*p) & (0x80 >> bit)) != 0) ? 0x01 : 0x00);
-                indexes[x+bit]=index;
-                *q++=image->colormap[(ssize_t) index];
+                SetPixelIndex(indexes+x+bit,index);
               }
             p++;
           }
@@ -146,36 +144,29 @@ static void InsertRow(ssize_t depth,unsigned char *p,ssize_t y,Image *image)
         for (x=0; x < ((ssize_t) image->columns-1); x+=2)
           {
             index=ConstrainColormapIndex(image,(*p >> 6) & 0x3);
-            indexes[x]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x,index);
             index=ConstrainColormapIndex(image,(*p >> 4) & 0x3);
-            indexes[x]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x,index);
             index=ConstrainColormapIndex(image,(*p >> 2) & 0x3);
-            indexes[x]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x,index);
             index=ConstrainColormapIndex(image,(*p) & 0x3);
-            indexes[x+1]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x+1,index);
             p++;
           }
         if ((image->columns % 4) != 0)
           {
             index=ConstrainColormapIndex(image,(*p >> 6) & 0x3);
-            indexes[x]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x,index);
             if ((image->columns % 4) >= 1)
 
               {
                 index=ConstrainColormapIndex(image,(*p >> 4) & 0x3);
-                indexes[x]=index;
-                *q++=image->colormap[(ssize_t) index];
+                SetPixelIndex(indexes+x,index);
                 if ((image->columns % 4) >= 2)
 
                   {
                     index=ConstrainColormapIndex(image,(*p >> 2) & 0x3);
-                    indexes[x]=index;
-                    *q++=image->colormap[(ssize_t) index];
+                    SetPixelIndex(indexes+x,index);
                   }
               }
             p++;
@@ -194,18 +185,15 @@ static void InsertRow(ssize_t depth,unsigned char *p,ssize_t y,Image *image)
         for (x=0; x < ((ssize_t) image->columns-1); x+=2)
           {
             index=ConstrainColormapIndex(image,(*p >> 4) & 0xf);
-            indexes[x]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x,index);
             index=ConstrainColormapIndex(image,(*p) & 0xf);
-            indexes[x+1]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x+1,index);
             p++;
           }
         if ((image->columns % 2) != 0)
           {
             index=ConstrainColormapIndex(image,(*p >> 4) & 0xf);
-            indexes[x]=index;
-            *q++=image->colormap[(ssize_t) index];
+            SetPixelIndex(indexes+x,index);
             p++;
           }
         if (SyncAuthenticPixels(image,exception) == MagickFalse)
@@ -217,14 +205,12 @@ static void InsertRow(ssize_t depth,unsigned char *p,ssize_t y,Image *image)
         q=QueueAuthenticPixels(image,0,y,image->columns,1,exception);
         if (q == (PixelPacket *) NULL) break;
         indexes=GetAuthenticIndexQueue(image);
-
         for (x=0; x < (ssize_t) image->columns; x++)
-          {
-            index=ConstrainColormapIndex(image,*p);
-            indexes[x]=index;
-            *q++=image->colormap[(ssize_t) index];
-            p++;
-          }
+        {
+          index=ConstrainColormapIndex(image,*p);
+          SetPixelIndex(indexes+x,index);
+          p++;
+        }
         if (SyncAuthenticPixels(image,exception) == MagickFalse)
           break;
       }
@@ -241,17 +227,17 @@ static int GetCutColors(Image *image)
   ExceptionInfo
     *exception;
 
-  ssize_t
-    x,
-    y;
-
-  PixelPacket
-    *q;
-
   Quantum
     intensity,
     scale_intensity;
 
+  register PixelPacket
+    *q;
+
+  ssize_t
+    x,
+    y;
+
   exception=(&image->exception);
   intensity=0;
   scale_intensity=ScaleCharToQuantum(16);
@@ -260,8 +246,8 @@ static int GetCutColors(Image *image)
     q=GetAuthenticPixels(image,0,y,image->columns,1,exception);
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      if (intensity < q->red)
-        intensity=q->red;
+      if (intensity < GetPixelRed(q))
+        intensity=GetPixelRed(q);
       if (intensity >= scale_intensity)
         return(255);
       q++;
@@ -319,9 +305,6 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   unsigned char *BImgBuff=NULL,*ptrB;
   PixelPacket *q;
 
-  ssize_t
-    count;
-
   /*
     Open image file.
   */
@@ -408,14 +391,14 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   (void) CopyMagickString(clone_info->filename+i,".PAL",(size_t)
     (MaxTextExtent-i));
-  if((clone_info->file=OpenMagickStream(clone_info->filename,"rb"))==NULL)
+  if((clone_info->file=fopen_utf8(clone_info->filename,"rb"))==NULL)
     {
       (void) CopyMagickString(clone_info->filename+i,".pal",(size_t)
         (MaxTextExtent-i));
-      if((clone_info->file=OpenMagickStream(clone_info->filename,"rb"))==NULL)
+      if((clone_info->file=fopen_utf8(clone_info->filename,"rb"))==NULL)
         {
           clone_info->filename[i]='\0';
-          if((clone_info->file=OpenMagickStream(clone_info->filename,"rb"))==NULL)
+          if((clone_info->file=fopen_utf8(clone_info->filename,"rb"))==NULL)
             {
               clone_info=DestroyImageInfo(clone_info);
               clone_info=NULL;
@@ -437,7 +420,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
   if(palette!=NULL)
     {
-      count=ReadBlob(palette,2,(unsigned char *) PalHeader.FileId);
+      (void) ReadBlob(palette,2,(unsigned char *) PalHeader.FileId);
       if(strncmp(PalHeader.FileId,"AH",2) != 0) goto ErasePalette;
       PalHeader.Version=ReadBlobLSBShort(palette);
       PalHeader.Size=ReadBlobLSBShort(palette);
@@ -449,7 +432,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       PalHeader.MaxRed=ReadBlobLSBShort(palette);
       PalHeader.MaxGreen=ReadBlobLSBShort(palette);
       PalHeader.MaxBlue=ReadBlobLSBShort(palette);
-      count=ReadBlob(palette,20,(unsigned char *) PalHeader.PaletteId);
+      (void) ReadBlob(palette,20,(unsigned char *) PalHeader.PaletteId);
 
       if(PalHeader.MaxIndex<1) goto ErasePalette;
       image->colors=PalHeader.MaxIndex+1;
@@ -532,8 +515,8 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       RunCount=(unsigned char) ReadBlobByte(image);
       RunCountMasked=RunCount & 0x7F;
 
-      while((int) RunCountMasked!=0)
-        {
+      while ((int) RunCountMasked != 0)
+      {
           if((ssize_t) RunCountMasked>j)
             {    /*Wrong Data*/
               RunCountMasked=(unsigned char) j;
@@ -549,7 +532,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
               (void) ResetMagickMemory(ptrB,(int) RunValue,(size_t) RunCountMasked);
             }
           else {
-            count=ReadBlob(image,(size_t) RunCountMasked,ptrB);
+            (void) ReadBlob(image,(size_t) RunCountMasked,ptrB);
           }
 
           ptrB+=(int) RunCountMasked;
@@ -562,6 +545,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
       InsertRow(depth,BImgBuff,i,image);
     }
+  (void) SyncImage(image);
 
 
   /*detect monochrome image*/
@@ -583,15 +567,18 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   if(image->colormap[i].blue!=sample) goto Finish;
                 }
 
-              image->colormap[1].red=image->colormap[1].green=image->colormap[1].blue=(Quantum) QuantumRange;
+              image->colormap[1].red=image->colormap[1].green=
+                image->colormap[1].blue=(Quantum) QuantumRange;
               for (i=0; i < (ssize_t)image->rows; i++)
                 {
                   q=QueueAuthenticPixels(image,0,i,image->columns,1,exception);
                   for (j=0; j < (ssize_t)image->columns; j++)
                     {
-                      if(q->red==ScaleCharToQuantum(1))
+                      if (GetPixelRed(q) == ScaleCharToQuantum(1))
                         {
-                          q->red=q->green=q->blue=(Quantum) QuantumRange;
+                          SetPixelRed(q,QuantumRange);
+                          SetPixelGreen(q,QuantumRange);
+                          SetPixelBlue(q,QuantumRange);
                         }
                       q++;
                     }
