@@ -54,6 +54,7 @@
 #include "magick/color-private.h"
 #include "magick/colormap.h"
 #include "magick/colorspace-private.h"
+#include "magick/distort.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/image.h"
@@ -67,7 +68,6 @@
 #include "magick/option.h"
 #include "magick/pixel.h"
 #include "magick/resource_.h"
-#include "magick/shear.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/module.h"
