@@ -126,9 +126,6 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Image
     *image;
 
-  ssize_t
-    y;
-
   MagickBooleanType
     status;
 
@@ -150,7 +147,8 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *q;
 
   ssize_t
-    count;
+    count,
+    y;
 
   unsigned char
     buffer[768];
@@ -206,9 +204,9 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   separations_mask=ReadBlobMSBShort(image);
   count=ReadBlob(image,14,buffer);
   buffer[14]='\0';
-  height=StringToDouble((char *) buffer);
+  height=StringToDouble((char *) buffer,(char **) NULL);
   count=ReadBlob(image,14,buffer);
-  width=StringToDouble((char *) buffer);
+  width=StringToDouble((char *) buffer,(char **) NULL);
   count=ReadBlob(image,12,buffer);
   buffer[12]='\0';
   image->rows=StringToUnsignedLong((char *) buffer);
@@ -245,25 +243,25 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           case 0:
           {
-            q->red=pixel;
-            q->green=pixel;
-            q->blue=pixel;
+            SetPixelRed(q,pixel);
+            SetPixelGreen(q,pixel);
+            SetPixelBlue(q,pixel);
             break;
           }
           case 1:
           {
-            q->green=pixel;
+            SetPixelGreen(q,pixel);
             break;
           }
           case 2:
           {
-            q->blue=pixel; break;
+            SetPixelBlue(q,pixel);
             break;
           }
           case 3: 
           {
             if (image->colorspace == CMYKColorspace)
-              indexes[x]=(IndexPacket) pixel;
+              SetPixelBlack(indexes+x,pixel);
             break;
           }
         }
@@ -275,7 +273,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (void) ReadBlobByte(image);  /* pad */
     }
     status=SetImageProgress(image,LoadImageTag,(MagickOffsetType) y,
-                image->rows);
+      image->rows);
     if (status == MagickFalse)
       break;
   }
