@@ -45,6 +45,7 @@
 #include "magick/colormap.h"
 #include "magick/colormap-private.h"
 #include "magick/constitute.h"
+#include "magick/distort.h"
 #include "magick/exception.h"
 #include "magick/exception-private.h"
 #include "magick/cache.h"
@@ -56,12 +57,12 @@
 #include "magick/memory_.h"
 #include "magick/resource_.h"
 #include "magick/quantum-private.h"
-#include "magick/shear.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
+#include "magick/utility-private.h"
 
 typedef struct
    {
@@ -749,7 +750,7 @@ static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
 
   /* Obtain temporary file */
   AcquireUniqueFilename(postscript_file);
-  ps_file=OpenMagickStream(postscript_file,"wb");
+  ps_file=fopen_utf8(postscript_file,"wb");
   if (ps_file == (FILE *) NULL)
     goto FINISH;
 
