@@ -364,13 +364,6 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
   ImageInfo
     *clone_info;
 
-  ssize_t
-    tile,
-    x,
-    x_offset,
-    y,
-    y_offset;
-
   MagickBooleanType
     concatenate,
     proceed,
@@ -379,12 +372,12 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
   MagickOffsetType
     tiles;
 
-  MagickStatusType
-    flags;
-
   MagickProgressMonitor
     progress_monitor;
 
+  MagickStatusType
+    flags;
+
   register ssize_t
     i;
 
@@ -393,15 +386,11 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     geometry,
     extract_info;
 
-  size_t
-    extent;
-
-  TypeMetric
-    metrics;
 
   size_t
     bevel_width,
     border_width,
+    extent,
     height,
     images_per_page,
     max_height,
@@ -415,6 +404,16 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     total_tiles,
     width;
 
+  ssize_t
+    tile,
+    x,
+    x_offset,
+    y,
+    y_offset;
+
+  TypeMetric
+    metrics;
+
   /*
     Create image tiles.
   */
@@ -510,7 +509,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       (void) ResetMagickMemory(&frame_info,0,sizeof(frame_info));
       frame_info.width=extract_info.width;
       frame_info.height=extract_info.height;
-      (void) FormatMagickString(absolute_geometry,MaxTextExtent,"%s!",
+      (void) FormatLocaleString(absolute_geometry,MaxTextExtent,"%s!",
         montage_info->frame);
       flags=ParseMetaGeometry(absolute_geometry,&frame_info.outer_bevel,
         &frame_info.inner_bevel,&frame_info.width,&frame_info.height);
@@ -636,8 +635,8 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     */
     (void) CopyMagickString(montage->filename,montage_info->filename,
       MaxTextExtent);
-    montage->columns=bounds.width;
-    montage->rows=bounds.height;
+    montage->columns=MagickMax(bounds.width,1);
+    montage->rows=MagickMax(bounds.height,1);
     (void) SetImageBackgroundColor(montage);
     /*
       Set montage geometry.
@@ -661,7 +660,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       GetMontageGeometry(montage_info->tile,number_images,&x_offset,&y_offset,
         &sans,&sans);
     y_offset+=(ssize_t) title_offset;
-    (void) FormatMagickString(montage->montage,MaxTextExtent,
+    (void) FormatLocaleString(montage->montage,MaxTextExtent,
       "%.20gx%.20g%+.20g%+.20g",(double) (extract_info.width+
       (extract_info.x+border_width)*2),(double) (extract_info.height+
       (extract_info.y+border_width)*2+(double) ((metrics.ascent-
@@ -698,7 +697,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
         clone_info->gravity=CenterGravity;
         clone_info->pointsize*=2.0;
         (void) GetTypeMetrics(image_list[0],clone_info,&metrics);
-        (void) FormatMagickString(geometry,MaxTextExtent,
+        (void) FormatLocaleString(geometry,MaxTextExtent,
           "%.20gx%.20g%+.20g%+.20g",(double) montage->columns,(double)
           (metrics.ascent-metrics.descent),0.0,(double) extract_info.y+4);
         (void) CloneString(&clone_info->geometry,geometry);
@@ -768,7 +767,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       tile_image->gravity=montage_info->gravity;
       if (image->gravity != UndefinedGravity)
         tile_image->gravity=image->gravity;
-      (void) FormatMagickString(tile_geometry,MaxTextExtent,"%.20gx%.20g+0+0",
+      (void) FormatLocaleString(tile_geometry,MaxTextExtent,"%.20gx%.20g+0+0",
         (double) image->columns,(double) image->rows);
       flags=ParseGravityGeometry(tile_image,tile_geometry,&geometry,exception);
       x=(ssize_t) (geometry.x+border_width);
@@ -835,7 +834,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
               /*
                 Annotate composite tile with label.
               */
-              (void) FormatMagickString(geometry,MaxTextExtent,
+              (void) FormatLocaleString(geometry,MaxTextExtent,
                 "%.20gx%.20g%+.20g%+.20g",(double) ((montage_info->frame ?
                 image->columns : width)-2*border_width),(double)
                 (metrics.ascent-metrics.descent+4)*MultilineCensus(value),
