@@ -24,8 +24,6 @@ extern "C" {
 
 #include <magick/thread_.h>
 
-#define omp_throttle(factor)  num_threads(omp_get_max_threads() >> (factor))
-
 #if (__GNUC__ > 3) || ((__GNUC__ == 3) && (__GNUC_MINOR > 10))
 #define MagickCachePrefetch(address,mode,locality) \
   __builtin_prefetch(address,mode,locality)
@@ -33,6 +31,9 @@ extern "C" {
 #define MagickCachePrefetch(address,mode,locality)
 #endif
 
+#define omp_throttle(factor)  num_threads(omp_get_max_threads() >> \
+   (factor) == 0 ? 1 : omp_get_max_threads() >> (factor))
+
 #if defined(MAGICKCORE_THREAD_SUPPORT)
   typedef pthread_mutex_t MagickMutexType;
 #elif defined(MAGICKCORE_WINDOWS_SUPPORT)
@@ -96,22 +97,20 @@ static inline MagickBooleanType IsMagickThreadEqual(const MagickThreadType id)
 */
 static inline size_t GetOpenMPMaximumThreads(void)
 {
+  static size_t
+    maximum_threads = 1;
+
 #if defined(MAGICKCORE_OPENMP_SUPPORT) && (_OPENMP >= 200203)
   {
     ssize_t
       threads;
 
-    static size_t
-      maximum_threads = 1UL;
-
     threads=omp_get_max_threads();
     if (threads > (ssize_t) maximum_threads)
       maximum_threads=threads;
-    return(maximum_threads);
   }
-#else
-  return(1UL);
 #endif
+  return(maximum_threads);
 }
 
 static inline int GetOpenMPThreadId(void)
