@@ -715,12 +715,12 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  CropImageToTiles() will crop a single image, into a possible list of tiles.
+%  CropImageToTiles() crops a single image, into a possible list of tiles.
 %  This may include a single sub-region of the image.  This basically applies
 %  all the normal geometry flags for Crop.
 %
-%      Image *CropImageToTiles(const Image *image,const RectangleInfo
-%         *crop_geometry, ExceptionInfo *exception)
+%      Image *CropImageToTiles(const Image *image,
+%        const RectangleInfo *crop_geometry, ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
@@ -758,30 +758,11 @@ MagickExport Image *CropImageToTiles(const Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-
   crop_image=NewImageList();
   next=NewImageList();
   flags=ParseGravityGeometry(image,crop_geometry,&geometry,exception);
-
   if ((flags & AreaValue) != 0)
     {
-      /*
-      MagickBooleanType
-        proceed;
-
-      MagickProgressMonitor
-        progress_monitor;
-
-      MagickOffsetType
-        i;
-
-      MagickSizeType
-        number_images;
-      */
-      size_t
-        height,
-        width;
-
       PointInfo
         delta,
         offset;
@@ -789,8 +770,12 @@ MagickExport Image *CropImageToTiles(const Image *image,
       RectangleInfo
         crop;
 
+      size_t
+        height,
+        width;
+
       /*
-        Crop into NxM tiles (@ flag)
+        Crop into NxM tiles (@ flag).
       */
       width=image->columns;
       height=image->rows;
@@ -808,74 +793,65 @@ MagickExport Image *CropImageToTiles(const Image *image,
           width+=(geometry.x < 0 ? -1 : 1)*geometry.x;
           height+=(geometry.y < 0 ? -1 : 1)*geometry.y;
         }
-      delta.x=(double) width/geometry.width;
-      delta.y=(double) height/geometry.height;
-      /*proceed=MagickTrue;
-      i=0;
-      number_images=geometry.width*geometry.height;*/
+      if ((width % geometry.width) != 0)
+        delta.x=(double) (width+(geometry.width >> 1))/geometry.width;
+      else
+        delta.x=(double) width/geometry.width;
+      if ((height % geometry.height) != 0)
+        delta.y=(double) (height+(geometry.height >> 1))/geometry.height;
+      else
+        delta.y=(double) height/geometry.height;
       for (offset.y=0; offset.y < (double) height; )
       {
         if ((flags & AspectValue) == 0)
           {
-            crop.y=(ssize_t) MagickRound((MagickRealType)
-              (offset.y-(geometry.y > 0 ? 0 : geometry.y)));
+            crop.y=(ssize_t) MagickRound((MagickRealType) (offset.y-
+              (geometry.y > 0 ? 0 : geometry.y)));
             offset.y+=delta.y;   /* increment now to find width */
-            crop.height=(size_t) MagickRound((MagickRealType)
-              (offset.y+(geometry.y < 0 ? 0 : geometry.y)));
+            crop.height=(size_t) MagickRound((MagickRealType) (offset.y+
+              (geometry.y < 0 ? 0 : geometry.y)));
           }
         else
           {
-            crop.y=(ssize_t) MagickRound((MagickRealType)
-              (offset.y-(geometry.y > 0 ? geometry.y : 0)));
+            crop.y=(ssize_t) MagickRound((MagickRealType) (offset.y-
+              (geometry.y > 0 ? geometry.y : 0)));
             offset.y+=delta.y;  /* increment now to find width */
-            crop.height=(size_t) MagickRound((MagickRealType)
-              (offset.y+(geometry.y < 0 ? geometry.y : 0)));
+            crop.height=(size_t) MagickRound((MagickRealType) (offset.y+
+              (geometry.y < 0 ? geometry.y : 0)));
           }
         crop.height-=crop.y;
         crop.y+=image->page.y;
         for (offset.x=0; offset.x < (double) width; )
         {
-          /*progress_monitor=SetImageProgressMonitor(image,
-            (MagickProgressMonitor) NULL,image->client_data);*/
           if ((flags & AspectValue) == 0)
             {
-              crop.x=(ssize_t) MagickRound((MagickRealType)
-                (offset.x-(geometry.x > 0 ? 0 : geometry.x)));
-              offset.x+=+delta.x;  /* increment now to find height*/
-              crop.width=(size_t) MagickRound((MagickRealType)
-                (offset.x+(geometry.x < 0 ? 0 : geometry.x)));
+              crop.x=(ssize_t) MagickRound((MagickRealType) (offset.x-
+                (geometry.x > 0 ? 0 : geometry.x)));
+              offset.x+=delta.x;  /* increment now to find height */
+              crop.width=(size_t) MagickRound((MagickRealType) (offset.x+
+                (geometry.x < 0 ? 0 : geometry.x)));
             }
           else
             {
               crop.x=(ssize_t) MagickRound((MagickRealType) (offset.x-
                 (geometry.x > 0 ? geometry.x : 0)));
-              offset.x+=+delta.x;  /* increment now to find height */
-              crop.width=(size_t) MagickRound((MagickRealType)
-                (offset.x+(geometry.x < 0 ? geometry.x : 0)));
+              offset.x+=delta.x;  /* increment now to find height */
+              crop.width=(size_t) MagickRound((MagickRealType) (offset.x+
+                (geometry.x < 0 ? geometry.x : 0)));
             }
           crop.width-=crop.x;
           crop.x+=image->page.x;
           next=CropImage(image,&crop,exception);
-          /*(void) SetImageProgressMonitor(image,progress_monitor,
-            image->client_data);
-          proceed=SetImageProgress(image,CropImageTag,i++,number_images);
-          if (proceed == MagickFalse)
-            break;
-          */
           if (next == (Image *) NULL)
             break;
-          /*(void) SetImageProgressMonitor(next,progress_monitor,
-            next->client_data);*/
           AppendImageToList(&crop_image,next);
         }
         if (next == (Image *) NULL)
           break;
-        /*if (proceed == MagickFalse)
-          break;*/
       }
+      ClearMagickException(exception);
       return(crop_image);
     }
-
   if (((geometry.width == 0) && (geometry.height == 0)) ||
       ((flags & XValue) != 0) || ((flags & YValue) != 0))
     {
@@ -892,23 +868,11 @@ MagickExport Image *CropImageToTiles(const Image *image,
         }
       return(crop_image);
      }
-
-  if ((image->columns > geometry.width) ||
-      (image->rows > geometry.height))
+  if ((image->columns > geometry.width) || (image->rows > geometry.height))
     {
-      /*
-      MagickBooleanType
-        proceed;
+      RectangleInfo
+        page;
 
-      MagickProgressMonitor
-        progress_monitor;
-
-      MagickOffsetType
-        i;
-
-      MagickSizeType
-        number_images;
-      */
       size_t
         height,
         width;
@@ -917,9 +881,6 @@ MagickExport Image *CropImageToTiles(const Image *image,
         x,
         y;
 
-      RectangleInfo
-        page;
-
       /*
         Crop into tiles of fixed size WxH.
       */
@@ -935,48 +896,24 @@ MagickExport Image *CropImageToTiles(const Image *image,
       if (height == 0)
         height=page.height;
       next=NewImageList();
-      /*proceed=MagickTrue;
-      i=0;
-      number_images=0;
-      for (y=0; y < (ssize_t) page.height; y+=(ssize_t) height)
-        for (x=0; x < (ssize_t) page.width; x+=(ssize_t) width)
-          number_images++;
-      */
       for (y=0; y < (ssize_t) page.height; y+=(ssize_t) height)
       {
         for (x=0; x < (ssize_t) page.width; x+=(ssize_t) width)
         {
-          /*progress_monitor=SetImageProgressMonitor(image,
-            (MagickProgressMonitor) NULL,image->client_data);*/
           geometry.width=width;
           geometry.height=height;
           geometry.x=x;
           geometry.y=y;
           next=CropImage(image,&geometry,exception);
-          /*(void) SetImageProgressMonitor(image,progress_monitor,
-            image->client_data);
-          proceed=SetImageProgress(image,CropImageTag,i++,number_images);
-          if (proceed == MagickFalse)
-            break;
-          */
           if (next == (Image *) NULL)
             break;
-          /*(void) SetImageProgressMonitor(next,progress_monitor,
-            next->client_data);*/
           AppendImageToList(&crop_image,next);
         }
         if (next == (Image *) NULL)
           break;
-        /*if (proceed == MagickFalse)
-          break;*/
-
       }
       return(crop_image);
     }
-  /*
-    Action of crop results in no change in image!
-    This is not an error so return a clone of the image!
-  */
   return(CloneImage(image,0,0,MagickTrue,exception));
 }
 
