@@ -58,6 +58,7 @@
 #include "magick/string_.h"
 #include "magick/token.h"
 #include "magick/utility.h"
+#include "magick/utility-private.h"
 #if defined(MAGICKCORE_HAVE_PROCESS_H)
 #include <process.h>
 #endif
@@ -196,7 +197,7 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
   destination_file=AcquireUniqueFileResource(destination);
   if (destination_file == -1)
     return(MagickFalse);
-  source_file=open(source,O_RDONLY | O_BINARY);
+  source_file=open_utf8(source,O_RDONLY | O_BINARY,0);
   if (source_file == -1)
     {
       (void) close(destination_file);
@@ -1102,124 +1103,6 @@ MagickExport ssize_t GetMagickPageSize(void)
 %   o  attributes: the path attributes are returned here.
 %
 */
-
-#if defined(MAGICKCORE_HAVE__WFOPEN)
-static size_t UTF8ToUTF16(const unsigned char *utf8,wchar_t *utf16)
-{
-  register const unsigned char
-    *p;
-
-  if (utf16 != (wchar_t *) NULL)
-    {
-      register wchar_t
-        *q;
-
-      wchar_t
-        c;
-
-      /*
-        Convert UTF-8 to UTF-16.
-      */
-      q=utf16;
-      for (p=utf8; *p != '\0'; p++)
-      {
-        if ((*p & 0x80) == 0)
-          *q=(*p);
-        else
-          if ((*p & 0xE0) == 0xC0)
-            {
-              c=(*p);
-              *q=(c & 0x1F) << 6;
-              p++;
-              if ((*p & 0xC0) != 0x80)
-                return(0);
-              *q|=(*p & 0x3F);
-            }
-          else
-            if ((*p & 0xF0) == 0xE0)
-              {
-                c=(*p);
-                *q=c << 12;
-                p++;
-                if ((*p & 0xC0) != 0x80)
-                  return(0);
-                c=(*p);
-                *q|=(c & 0x3F) << 6;
-                p++;
-                if ((*p & 0xC0) != 0x80)
-                  return(0);
-                *q|=(*p & 0x3F);
-              }
-            else
-              return(0);
-        q++;
-      }
-      *q++='\0';
-      return(q-utf16);
-    }
-  /*
-    Compute UTF-16 string length.
-  */
-  for (p=utf8; *p != '\0'; p++)
-  {
-    if ((*p & 0x80) == 0)
-      ;
-    else
-      if ((*p & 0xE0) == 0xC0)
-        {
-          p++;
-          if ((*p & 0xC0) != 0x80)
-            return(0);
-        }
-      else
-        if ((*p & 0xF0) == 0xE0)
-          {
-            p++;
-            if ((*p & 0xC0) != 0x80)
-              return(0);
-            p++;
-            if ((*p & 0xC0) != 0x80)
-              return(0);
-         }
-       else
-         return(0);
-  }
-  return(p-utf8);
-}
-
-static wchar_t *ConvertUTF8ToUTF16(const unsigned char *source)
-{
-  size_t
-    length;
-
-  wchar_t
-    *utf16;
-
-  length=UTF8ToUTF16(source,(wchar_t *) NULL);
-  if (length == 0)
-    {
-      register ssize_t
-        i;
-
-      /*
-        Not UTF-8, just copy.
-      */
-      length=strlen((const char *) source);
-      utf16=(wchar_t *) AcquireQuantumMemory(length+1,sizeof(*utf16));
-      if (utf16 == (wchar_t *) NULL)
-        return((wchar_t *) NULL);
-      for (i=0; i <= (ssize_t) length; i++)
-        utf16[i]=source[i];
-      return(utf16);
-    }
-  utf16=(wchar_t *) AcquireQuantumMemory(length+1,sizeof(*utf16));
-  if (utf16 == (wchar_t *) NULL)
-    return((wchar_t *) NULL);
-  length=UTF8ToUTF16(source,utf16);
-  return(utf16);
-}
-#endif
-
 MagickExport MagickBooleanType GetPathAttributes(const char *path,
   void *attributes)
 {
@@ -1231,21 +1114,8 @@ MagickExport MagickBooleanType GetPathAttributes(const char *path,
       errno=EINVAL;
       return(MagickFalse);
     }
-#if !defined(MAGICKCORE_HAVE__WSTAT)
-  status=stat(path,(struct stat *) attributes) == 0 ? MagickTrue : MagickFalse;
-#else
-  {
-    wchar_t
-      *unicode_path;
-
-    unicode_path=ConvertUTF8ToUTF16((const unsigned char *) path);
-    if (unicode_path == (wchar_t *) NULL)
-      return(MagickFalse);
-    status=wstat(unicode_path,(struct stat *) attributes) == 0 ? MagickTrue :
-      MagickFalse;
-    unicode_path=(wchar_t *) RelinquishMagickMemory(unicode_path);
-  }
-#endif
+  status=stat_utf8(path,(struct stat *) attributes) == 0 ? MagickTrue :
+    MagickFalse;
   return(status);
 }
 
@@ -1298,6 +1168,35 @@ MagickExport void GetPathComponent(const char *path,PathType type,
     }
   (void) CopyMagickString(component,path,MaxTextExtent);
   *magick='\0';
+#if defined(__OS2__)
+  if (path[1] != ":")
+#endif
+  for (p=component; *p != '\0'; p++)
+  {
+    if ((*p == '%') && (*(p+1) == '['))
+      {
+        /*
+          Skip over %[...].
+        */
+        for (p++; (*p != ']') && (*p != '\0'); p++) ;
+        if (*p == '\0')
+          break;
+      }
+    if ((*p == ':') && (IsPathDirectory(path) < 0) &&
+        (IsPathAccessible(path) == MagickFalse))
+      {
+        /*
+          Look for image format specification (e.g. ps3:image).
+        */
+        (void) CopyMagickString(magick,component,(size_t) (p-component+1));
+        if (IsMagickConflict(magick) != MagickFalse)
+          *magick='\0';
+        else
+          for (q=component; *q != '\0'; q++)
+            *q=(*++p);
+        break;
+      }
+  }
   *subimage='\0';
   p=component;
   if (*p != '\0')
@@ -1322,35 +1221,6 @@ MagickExport void GetPathComponent(const char *path,PathType type,
             *q='\0';
         }
     }
-#if defined(__OS2__)
-  if (path[1] != ':')
-#endif
-  for (p=component; *p != '\0'; p++)
-  {
-    if ((*p == '%') && (*(p+1) == '['))
-      {
-        /*
-          Skip over %[...].
-        */
-        for (p++; (*p != ']') && (*p != '\0'); p++) ;
-        if (*p == '\0')
-          break;
-      }
-    if ((*p == ':') && (IsPathDirectory(component) < 0) &&
-        (IsPathAccessible(component) == MagickFalse))
-      {
-        /*
-          Look for image format specification (e.g. ps3:image).
-        */
-        (void) CopyMagickString(magick,component,(size_t) (p-component+1));
-        if (IsMagickConflict(magick) != MagickFalse)
-          *magick='\0';
-        else
-          for (q=component; *q != '\0'; q++)
-            *q=(*++p);
-        break;
-      }
-  }
   p=component;
   if (*p != '\0')
     for (p=component+strlen(component)-1; p > component; p--)
@@ -1528,7 +1398,7 @@ MagickExport MagickBooleanType IsPathAccessible(const char *path)
     return(status);
   if (S_ISREG(attributes.st_mode) == 0)
     return(MagickFalse);
-  if (access(path,F_OK) != 0)
+  if (access_utf8(path,F_OK) != 0)
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -1891,67 +1761,6 @@ MagickExport size_t MultilineCensus(const char *label)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   O p e n M a g i c k S t r e a m                                           %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  OpenMagickStream() opens the file at the specified path and return the
-%  associated stream.
-%
-%  The path of the OpenMagickStream method is:
-%
-%      FILE *OpenMagickStream(const char *path,const char *mode)
-%
-%  A description of each parameter follows.
-%
-%   o  path: the file path.
-%
-%   o  mode: the file mode.
-%
-*/
-MagickExport FILE *OpenMagickStream(const char *path,const char *mode)
-{
-  FILE
-    *file;
-
-  if ((path == (const char *) NULL) || (mode == (const char *) NULL))
-    {
-      errno=EINVAL;
-      return((FILE *) NULL);
-    }
-  file=(FILE *) NULL;
-#if defined(MAGICKCORE_HAVE__WFOPEN)
-  {
-    wchar_t
-      *unicode_mode,
-      *unicode_path;
-
-    unicode_path=ConvertUTF8ToUTF16((const unsigned char *) path);
-    if (unicode_path == (wchar_t *) NULL)
-      return((FILE *) NULL);
-    unicode_mode=ConvertUTF8ToUTF16((const unsigned char *) mode);
-    if (unicode_mode == (wchar_t *) NULL)
-      {
-        unicode_path=(wchar_t *) RelinquishMagickMemory(unicode_path);
-        return((FILE *) NULL);
-      }
-    file=_wfopen(unicode_path,unicode_mode);
-    unicode_mode=(wchar_t *) RelinquishMagickMemory(unicode_mode);
-    unicode_path=(wchar_t *) RelinquishMagickMemory(unicode_path);
-  }
-#endif
-  if (file == (FILE *) NULL)
-    file=fopen(path,mode);
-  return(file);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   S y s t e m C o m m a n d                                                 %
 %                                                                             %
 %                                                                             %
