@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -40,9 +40,6 @@ extern MagickExport char
   **GetPathComponents(const char *,size_t *),
   **ListFiles(const char *,const char *,size_t *);
 
-extern MagickExport FILE
-  *OpenMagickStream(const char *,const char *);
-
 extern MagickExport int
   SystemCommand(const MagickBooleanType,const MagickBooleanType,const char *,
     ExceptionInfo *);
@@ -69,7 +66,8 @@ extern MagickExport void
   AppendImageFormat(const char *,char *),
   ChopPathComponents(char *,const size_t),
   ExpandFilename(char *),
-  GetPathComponent(const char *,PathType,char *);
+  GetPathComponent(const char *,PathType,char *),
+  MagickDelay(const MagickSizeType);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
