@@ -27,15 +27,15 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2011 ImageMagick Studio LLC"
-#define MagickSVNRevision  "exported"
-#define MagickLibVersion  0x672
-#define MagickLibVersionText  "6.7.2"
+#define MagickSVNRevision  "6106"
+#define MagickLibVersion  0x673
+#define MagickLibVersionText  "6.7.3"
 #define MagickLibVersionNumber  5,0,0
 #define MagickLibAddendum  "-10"
 #define MagickLibInterface  5
 #define MagickLibMinInterface  5
-#define MagickReleaseDate  "2011-10-05"
-#define MagickChangeDate   "20111004"
+#define MagickReleaseDate  "2011-12-01"
+#define MagickChangeDate   "20111129"
 #define MagickAuthoritativeURL  "http://www.imagemagick.org"
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
 #define MagickOpenMPFeature  "OpenMP "
@@ -58,7 +58,7 @@ extern "C" {
 #define MagickZeroConfigurationFeature  " "
 #endif
 #define MagickFeatures MagickOpenMPFeature MagickOpenCLFeature MagickHDRIFeature MagickZeroConfigurationFeature
-#define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6.7.2//index.html"
+#define MagickHomeURL  "file:///usr/share/doc/ImageMagick//index.html"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
 #define MagickQuantumDepth  "Q8"
 #define MagickQuantumRange  "255"
