@@ -511,11 +511,11 @@ WandExport PixelWand **PixelGetCurrentIteratorRow(PixelIterator *iterator,
   if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
     for (x=0; x < (ssize_t) iterator->region.width; x++)
       PixelSetBlackQuantum(iterator->pixel_wands[x],
-        GetBlackPixelComponent(indexes+x));
+        GetPixelBlack(indexes+x));
   if (GetCacheViewStorageClass(iterator->view) == PseudoClass)
     for (x=0; x < (ssize_t) iterator->region.width; x++)
       PixelSetIndex(iterator->pixel_wands[x],
-        GetBlackPixelComponent(indexes+x));
+        GetPixelBlack(indexes+x));
   *number_wands=iterator->region.width;
   return(iterator->pixel_wands);
 }
@@ -704,11 +704,11 @@ WandExport PixelWand **PixelGetNextIteratorRow(PixelIterator *iterator,
   if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
     for (x=0; x < (ssize_t) iterator->region.width; x++)
       PixelSetBlackQuantum(iterator->pixel_wands[x],
-        GetBlackPixelComponent(indexes+x));
+        GetPixelBlack(indexes+x));
   if (GetCacheViewStorageClass(iterator->view) == PseudoClass)
     for (x=0; x < (ssize_t) iterator->region.width; x++)
       PixelSetIndex(iterator->pixel_wands[x],
-        GetIndexPixelComponent(indexes+x));
+        GetPixelIndex(indexes+x));
   *number_wands=iterator->region.width;
   return(iterator->pixel_wands);
 }
@@ -784,11 +784,11 @@ WandExport PixelWand **PixelGetPreviousIteratorRow(PixelIterator *iterator,
   if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
     for (x=0; x < (ssize_t) iterator->region.width; x++)
       PixelSetBlackQuantum(iterator->pixel_wands[x],
-        GetBlackPixelComponent(indexes+x));
+        GetPixelBlack(indexes+x));
   if (GetCacheViewStorageClass(iterator->view) == PseudoClass)
     for (x=0; x < (ssize_t) iterator->region.width; x++)
       PixelSetIndex(iterator->pixel_wands[x],
-        GetIndexPixelComponent(indexes+x));
+        GetPixelIndex(indexes+x));
   *number_wands=iterator->region.width;
   return(iterator->pixel_wands);
 }
@@ -984,7 +984,7 @@ WandExport MagickBooleanType PixelSyncIterator(PixelIterator *iterator)
     PixelGetQuantumColor(iterator->pixel_wands[x],pixels+x);
   if (GetCacheViewColorspace(iterator->view) == CMYKColorspace)
     for (x=0; x < (ssize_t) iterator->region.width; x++)
-      SetBlackPixelComponent(indexes+x,PixelGetBlackQuantum(
+      SetPixelBlack(indexes+x,PixelGetBlackQuantum(
         iterator->pixel_wands[x]));
   if (SyncCacheViewAuthenticPixels(iterator->view,exception) == MagickFalse)
     {
